@@ -1,3 +1,4 @@
+from pdb import set_trace as T
 from torch import nn
 
 
@@ -6,6 +7,10 @@ class BatchFirstLSTM(nn.LSTM):
         super().__init__(*args, batch_first=True, **kwargs)
 
     def forward(self, input, hx):
+        '''
+        input: B x T x H
+        h&c: B x T x H
+        '''
         h, c       = hx
         h          = h.transpose(0, 1)
         c          = c.transpose(0, 1)
